
bootstrap.model <- function(response.vector, Predictors, Data, n){
  
  # function taken from https://www.polarmicrobes.org/analyzing-broad-data-with-glmnet/
  
  ## The function requires as input the response vector, a vector of the predictors,
  ## the data frame of predictors, and the number of iterations you want to run. 

  predictor.df <- as.data.frame(Data[,Predictors])
  colnames(predictor.df) <- Predictors
  model.predictions <- matrix(ncol = 3, nrow = 0)
  colnames(model.predictions) <- c('year', 'prediction', 'real')
  
  ## How many observations you need to withhold is determined by how many
  ## iterations you want to run.  For example, for 1000 iterations of
  ## unique random subsets of 19 observations, you need to withold 3.
  
  x <- 0
  boot <- 0
  
  for(y in (length(response.vector) - 1):1){
    while(x < n){
      boot <- boot + 1
      x <- y ** boot
      print(x)
    }
  }
  
  ## Now build n new models.
  adjR2 <- matrix(ncol = 1, nrow = 1000)
  adjtestR2 <- matrix(ncol = 1, nrow = 1000)
  for(i in 1:n){
    print(i)
    predict.i <- sample.int(length(response.vector), boot)
    train.i <- which(!1:length(response.vector) %in% predict.i)
    
    temp.model <- lm(response.vector ~ ., data = predictor.df, subset = train.i)
    adj = summary(temp.model)
    adjR2[i,1] = adj$adj.r.squared
    
    new.data <- as.data.frame(predictor.df[predict.i,])
    colnames(new.data) <- Predictors
    
    temp.predict <- predict(temp.model, newdata = new.data, type = 'response')
    temp.actual <- response.vector[predict.i]
    
    temp.out <- matrix(ncol = 3, nrow = boot)
    try({temp.out[,1] <- names(response.vector)[predict.i]}, silent = T)
    temp.out[,2] <- temp.predict
    temp.out[,3] <- temp.actual
    
    temp.model <- lm(temp.predict ~ temp.actual)
    adjtest = summary(temp.model)
    adjtestR2[i,1] = adjtest$adj.r.squared
    
    
    model.predictions <- rbind(model.predictions, temp.out)
    
  }
  
  mean.predicted <- as.data.frame(tapply(as.numeric(model.predictions[,2]), as.character(model.predictions[,3]), mean))
  sd.predicted <- as.data.frame(tapply(as.numeric(model.predictions[,2]), as.character(model.predictions[,3]), sd))
  
  ## Plot
  
  plot(mean.predicted[,1] ~ as.numeric(row.names(mean.predicted)),
       ylab = 'Predicted response',
       xlab = 'Observed response',
       pch = 19,cex = .5,
       frame.plot=FALSE, xlim=c(-1, 4),ylim=c(-1, 4)      )
  
  for(r in row.names(mean.predicted)){
    lines(c(as.numeric(r), as.numeric(r)), c(mean.predicted[r,1], mean.predicted[r,1] + sd.predicted[r,1]))
    lines(c(as.numeric(r), as.numeric(r)), c(mean.predicted[r,1], mean.predicted[r,1] - sd.predicted[r,1]))
  }
  
  abline(0, 1, lty = 2, lwd =3, col="red")
  
  mean.lm <- lm(mean.predicted[,1] ~ as.numeric(row.names(mean.predicted)))
  abline(mean.lm,lwd =3)
  print(summary(mean.lm))
  
  
  ## Save results in a list.
  
  list.out <- list()
  list.out$model.predictions <- model.predictions
  list.out$mean.lm <- mean.lm
  list.out$mean.predicted <- mean.predicted
  list.out$sd.predicted <- sd.predicted
  
  return(list.out)
  
}

