#!/bin/sh
#
# Aim: Sum all lesions' masks and create probability maps thresholded with 50% and 75%. The volume for both hemispheres and for both probability maps is also computed.
#
# Input: lesions' masks
# Output: sum mask, probability maps, volume of lesion for each probability map and hemisphere
#
#############################################
# Author: Nadia Moreira da Silva
#         Newcastle University, Uk
#############################################

fsldir=/usr/local/fsl
rootDir=/Users/nadia/Documents/Projects/Project@TBI/Processing@Data/Lesion_Maps/Lesions_Longitudinal_Study
outputDir=/Users/nadia/Documents/Projects/Project@TBI/Processing@Data/Lesion_Maps
refDir=/usr/local/fsl/data/standard


echo START: 1. Generate blank image
${fsldir}/bin/fslmaths $rootDir/lesion2MNI_H01.nii.gz -mul 0 $outputDir/sum_mask.nii.gz
echo END: 1. Generate blank image

echo START: 2. SUM MASKS
for d in ${rootDir}/*; do
${fsldir}/bin/fslmaths $d -add $outputDir/sum_mask.nii.gz $outputDir/sum_mask.nii.gz
done
echo Multiply by brain MNI mask
${fsldir}/bin/fslmaths $outputDir/sum_mask.nii.gz -mul ${refDir}/MNI152_T1_2mm_brain_mask.nii.gz $outputDir/sum_mask.nii.gz
echo END: 2. SUM MASKS

echo START: 3. Create Probability Map: divide voxels by the maximum value
minmax=`${fsldir}/bin/fslstats $outputDir/sum_mask.nii.gz -R`
max=`echo "$minmax" | cut -d ' ' -f 2`
echo $max
${fsldir}/bin/fslmaths $outputDir/sum_mask.nii.gz -div $max $outputDir/Probability_Lesion_Map.nii.gz
echo END: 3. Create Probability Map: divide voxels by the maximum value

echo START: 4. Threshold Probability Map with 0.5
${fsldir}/bin/fslmaths $outputDir/Probability_Lesion_Map.nii.gz -thr 0.5 $outputDir/Probability_Lesion_Map_50.nii.gz
echo END: 4. Threshold Probability Map with 0.5

echo START: 6. Generate two masks /for both hemispheres of Probability Maps of 50%
${fsldir}/bin/fslroi $outputDir/Probability_Lesion_Map_50.nii.gz $outputDir/Probability_Lesion_Map_50_R.nii.gz 0 46 0 109 0 91
${fsldir}/bin/fslroi $outputDir/Probability_Lesion_Map_50.nii.gz $outputDir/Probability_Lesion_Map_50_L.nii.gz 46 44 0 109 0 91
echo END: Generate two masks /for both hemispheres of Probability Map 50%

echo START: Calculate lesion volume by hemisphere
vol_50_R=`${fsldir}/bin/fslstats $outputDir/Probability_Lesion_Map_50_R.nii.gz -V`
vol_50_L=`${fsldir}/bin/fslstats $outputDir/Probability_Lesion_Map_50_L.nii.gz -V`

echo Right Side Volume: Probability Map of 50%
echo $vol_50_R
echo Left Side Volume: Probability Map of 50%
echo $vol_50_L
echo END: Calculate lesion volume by hemisphere
